# Loading all necessary packages for PCoA
library(tidyverse)
library(vegan)
library(ape)
library(phyloseq)
library(DESeq2)
library(ggplot2)
library(ggthemes)

# Setting seed
set.seed(711)

# Defining metadata 
metadata_file <- "hiseas_metadata.txt"

# Load the metadata file
dat <- read_tsv(metadata_file)

# Import QIIME2 Data for overall and each of the 3 time points 
overall_biom_file <- import_biom("overall-table-with-taxonomy.biom")
group1_biom_file <- import_biom("group1-table-with-taxonomy.biom")
group2_biom_file <- import_biom("group2-table-with-taxonomy.biom")
group3_biom_file <- import_biom("group3-table-with-taxonomy.biom")
metadata <- import_qiime_sample_data("hiseas_metadata.txt")
tree <- read_tree_greengenes("tree.nwk")

# Change collection_timestamp to a categorical variable
metadata$collection_timestamp <- as.factor(metadata$collection_timestamp)

# Convert from multichotomous to dichotomous tree
tree <- multi2di(tree)

# Combine all data into a single phyloseq object
overall_physeq <- merge_phyloseq(overall_biom_file, metadata, tree)
group1_physeq <- merge_phyloseq(group1_biom_file, metadata, tree)
group2_physeq<- merge_phyloseq(group2_biom_file, metadata, tree)
group3_physeq <- merge_phyloseq(group3_biom_file, metadata, tree)

# Subset to first and last time point
overall_physeq <- subset_samples(overall_physeq, 
                                      collection_timestamp %in% c("2015-09-04", 
                                                                  "2016-08-05" ))

# Assign taxonomic level
colnames(tax_table(overall_physeq)) <- c("Kingdom", "Phylum", "Class", "Order", "Family", "Genus", "Species")
colnames(tax_table(group1_physeq)) <- c("Kingdom", "Phylum", "Class", "Order", "Family", "Genus", "Species")
colnames(tax_table(group2_physeq)) <- c("Kingdom", "Phylum", "Class", "Order", "Family", "Genus", "Species")
colnames(tax_table(group3_physeq)) <- c("Kingdom", "Phylum", "Class", "Order", "Family", "Genus", "Species")

# Setting rarefaction depth 
overall_rar <- rarefy_even_depth(overall_physeq, sample.size = 15720)
group1_rar <- rarefy_even_depth(group1_physeq, sample.size = 15720)
group2_rar <- rarefy_even_depth(group2_physeq, sample.size = 15720)
group3_rar <- rarefy_even_depth(group3_physeq, sample.size = 15720)

# Calculate diversity metrics 
ord_overall <- ordinate(overall_rar, method = "PCoA", distance = "wunifrac")
ord_g1 <- ordinate(group1_rar, method = "PCoA", distance = "wunifrac")
ord_g2 <- ordinate(group2_rar, method = "PCoA", distance = "wunifrac")
ord_g3 <- ordinate(group3_rar, method = "PCoA", distance = "wunifrac")

# Plotting PCoA for overall weighted unifrac beta diversity
pcoa_overall_wunifrac <- plot_ordination(overall_rar,
                                         ord_overall,
                                         color = "collection_timestamp", shape = "crew_interaction") +
  labs(title = "PCoA (weighted UniFrac) Overall") +
  theme_few() + 
  stat_ellipse(type = "norm", size = 0.5)

ggsave("pcoa_overall_wunifrac.png", pcoa_overall_wunifrac, width = 8, height = 6)

# Plotting PCoA time points 1-3
pcoa_group1_wunifrac <- plot_ordination(group1_rar,
                                        ord_g1,
                                        color = "crew_interaction") +
  labs(title = "PCoA (weighted UniFrac) Time Points 1-3") +
  theme_few() + 
  stat_ellipse(type = "norm", size = 0.5)

ggsave("pcoa_group1_wunifrac.png", pcoa_group1_wunifrac, width = 8, height = 6)

# Plotting PCoA time points 4-6
pcoa_group2_wunifrac <- plot_ordination(group2_rar,
                                        ord_g2,
                                        color = "crew_interaction") +
  labs(title = "PCoA (weighted UniFrac) Time Points 4-6") +
  theme_few() + 
  stat_ellipse(type = "norm", size = 0.5)

ggsave("pcoa_group2_wunifrac.png", pcoa_group2_wunifrac, width = 8, height = 6)

# Plotting PCoA time points 7-9
pcoa_group3_wunifrac <- plot_ordination(group3_rar,
                                        ord_g3,
                                        color = "crew_interaction") +
  labs(title = "PCoA (weighted UniFrac) Time Points 7-9") +
  theme_few() + 
  stat_ellipse(type = "norm", size = 0.5, level = 0.95)

ggsave("pcoa_group3_wunifrac.png", pcoa_group3_wunifrac, width = 8, height = 6)

