# Loading all necessary packages for differential abundance
library(tidyverse)
library(vegan)
library(ape)
library(phyloseq)
library(DESeq2)
library(ggplot2)
library(ggthemes)

# Setting seed
set.seed(711)

# Defining metadata 
metadata_file <- "hiseas_metadata.txt"

# Load the metadata file
dat <- read_tsv(metadata_file)

# Import QIIME2 Data for overall and each of the 3 time points 
overall_biom_file <- import_biom("overall-table-with-taxonomy.biom")
group1_biom_file <- import_biom("group1-table-with-taxonomy.biom")
group2_biom_file <- import_biom("group2-table-with-taxonomy.biom")
group3_biom_file <- import_biom("group3-table-with-taxonomy.biom")
metadata <- import_qiime_sample_data("hiseas_metadata.txt")
tree <- read_tree_greengenes("tree.nwk")

# Change collection_timestamp to a categorical variable
metadata$collection_timestamp <- as.factor(metadata$collection_timestamp)

# Convert from multichotomous to dichotomous tree
tree <- multi2di(tree)

# Combine all data into a single phyloseq object
overall_physeq <- merge_phyloseq(overall_biom_file, metadata, tree)
group1_physeq <- merge_phyloseq(group1_biom_file, metadata, tree)
group2_physeq<- merge_phyloseq(group2_biom_file, metadata, tree)
group3_physeq <- merge_phyloseq(group3_biom_file, metadata, tree)

#Assign new taxonomic rank column names
colnames(tax_table(overall_physeq)) <- c("Kingdom", "Phylum", "Class", "Order",
                                 "Family", "Genus", "Species")

# Providing custom function
calculate_relative_abundance <- function(x) x / sum(x)
calculate_gm_mean <- function(x, na.rm = TRUE) {
  exp(sum(log(x[x > 0]), na.rm = na.rm) / length(x))
}

# Set taxonomic level
overall_taxa <- tax_glom(overall_physeq, taxrank = "Genus")

# Additional subset for initial and final collection time point
overall_taxa_subset <- subset_samples(overall_taxa, 
                                      collection_timestamp %in% c("2015-09-04", 
                                                                  "2016-08-05" ))
# DESeq2 Analysis
sample_data(overall_taxa_subset)$collection_timestamp <-
  factor(sample_data(overall_taxa_subset)$collection_timestamp,
         levels = c("2015-09-04", "2016-08-05"))

deseq_overall <- phyloseq_to_deseq2(overall_taxa_subset, ~ collection_timestamp)
geo_means <- apply(counts(deseq_overall), 1, calculate_gm_mean)
deseq_overall <- estimateSizeFactors(deseq_overall, geoMeans = geo_means)
deseq_overall <- DESeq(deseq_overall, fitType = "local")

# Created object for differential abundance
diff_abund_overall <- results(deseq_overall)

# Determine significant results
alpha <- 0.05
significant_overall <- as.data.frame(diff_abund_overall)

# Filtering out table to only include significant 
significant_overall <- dplyr::filter(significant_overall, padj < alpha)

genera_df <- as.data.frame(tax_table(overall_taxa_subset))
significant_overall <- merge(significant_overall, genera_df, by = "row.names")
significant_overall <- arrange(significant_overall, log2FoldChange)
significant_overall <- mutate(significant_overall, Genus = factor(Genus, levels = Genus))

# Generating visualization
ggplot(significant_overall, aes(x = log2FoldChange, y = Genus)) +
  geom_bar(stat = "identity") + 
  labs(title = "Differential Genera between Baseline & Final Timestamps", 
       x = "log2 fold-change",
       y = "Genus") +
  theme_few()






